@@ -3,6 +3,11 @@ context("plotting functions")
 
 test_that("plot_confusion_matrix() returns expected plots", {
 
+  if (!requireNamespace("rsvg", quietly = TRUE) ||
+      !requireNamespace("ggimage", quietly = TRUE)) {
+    testthat::skip("missing 'rsvg' and/or 'ggimage'.")
+  }
+
   # Note: These are just initial tests
   # There's probably a high number of errors it won't catch
 
@@ -82,6 +87,11 @@ test_that("plot_confusion_matrix() returns expected plots", {
 
 test_that("plot_confusion_matrix() with multiclass conf mat returns expected plots", {
 
+  if (!requireNamespace("rsvg", quietly = TRUE) ||
+      !requireNamespace("ggimage", quietly = TRUE)) {
+    testthat::skip("missing 'rsvg' and/or 'ggimage'.")
+  }
+
   # Note: These are just initial tests
   # There's probably a high number of errors it won't catch
 
